import os

FRIDA_SERVER_PATH = '/data/local/tmp/frida-server'
LOCAL_FRIDA_SERVER_PATH = os.path.join(os.path.dirname(__file__), '/bin/frida_server')
FRIDA_DEVICE_TYPE = 'usb'
AUTOMATIC_LOADING_DEVICE = True

# 在加载时如果env中设置了环境变量FRIDA_SERVER_PATH，那么就会调用set_frida_server_path方法
if 'FRIDA_SERVER_PATH' in os.environ:
    FRIDA_SERVER_PATH = os.environ['FRIDA_SERVER_PATH']

if 'FRIDA_DEVICE_TYPE' in os.environ:
    FRIDA_DEVICE_TYPE = os.environ['FRIDA_DEVICE_TYPE']

if 'LOCAL_FRIDA_SERVER_PATH' in os.environ:
    LOCAL_FRIDA_SERVER_PATH = os.environ['LOCAL_FRIDA_SERVER_PATH']



import unittest
import frida
import subprocess
from unittest.mock import Mock
from frida_devices_manager.core import Core


class TestCore(unittest.TestCase):

    def setUp(self):
        self.device = Mock(spec=frida.core.Device)
        self.device.id = "12345"
        self.core = Core(self.device)

    def test_eq(self):
        other = Core(self.device)
        self.assertTrue(self.core.__eq__(other))

        other_str = "12345"
        self.assertTrue(self.core.__eq__(other_str))

        other = "56789"
        self.assertFalse(self.core.__eq__(other))

        other_device = Mock(spec=frida.core.Device)
        other_device.id = "56789"
        other = Core(other_device)
        self.assertFalse(self.core.__eq__(other))
        self.assertFalse(self.core.__eq__(other_device))

    def test_ne(self):
        other = Core(self.device)
        self.assertFalse(self.core.__ne__(other))

        other_str = "12345"
        self.assertFalse(self.core.__ne__(other_str))

        other = "56789"
        self.assertTrue(self.core.__ne__(other))

        other_device = Mock(spec=frida.core.Device)
        other_device.id = "56789"
        other = Core(other_device)
        self.assertTrue(self.core.__ne__(other))
        self.assertTrue(self.core.__ne__(other_device))

    def test_is_frida_running(self):
        frida.get_device = Mock(side_effect=frida.ServerNotRunningError)
        result = self.core.is_frida_running()
        self.assertFalse(result)

    def test_is_frida_installed(self):
        subprocess.check_output = Mock(return_value="true\n")
        result = self.core.is_frida_installed()
        self.assertTrue(result)

        subprocess.check_output = Mock(return_value="false\n")
        result = self.core.is_frida_installed()
        self.assertFalse(result)

        subprocess.check_output = Mock(
            side_effect=subprocess.CalledProcessError(-1, 'bogus')
        )
        result = self.core.is_frida_installed()
        self.assertFalse(result)

    def test_copy_frida_server_to_device(self):
        subprocess.run = Mock()
        self.core.copy_frida_server_to_device()
        subprocess.run.assert_called_once()

    def test_run_frida_server(self):
        subprocess.run = Mock()
        self.core.run_frida_server()
        subprocess.run.assert_called_once()

    def test_get_all_connected_devices(self):
        device1 = Mock(spec=frida.core.Device)
        device1.type = "device"
        device2 = Mock(spec=frida.core.Device)
        device2.type = "usb"
        device_list = [device1, device2]
        frida.get_device_manager = Mock(
            return_value=Mock(enumerate_devices=Mock(return_value=device_list))
        )
        result = Core.get_all_connected_devices()
        self.assertEqual(len(result), 2)


if __name__ == "__main__":
    unittest.main()



import setuptools

import frida_devices_manager

with open("README.md", "r",encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name=frida_devices_manager.name,
    version=frida_devices_manager.__version__,
    author="369",
    author_email="luck.yangbo@gmail.com",
    description="A simple frida devices manager",
    long_description=long_description,
    long_description_content_type="text/markdown",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)



import frida.core
import subprocess

from frida_devices_manager.constants import FRIDA_SERVER_PATH, LOCAL_FRIDA_SERVER_PATH


class Core:
    __frida_device: frida.core.Device

    def __init__(self, device: frida.core.Device):
        self.__frida_device = device

    def __eq__(self, other):
        if isinstance(other, str):
            return self.__frida_device.id == other
        elif isinstance(other, frida.core.Device):
            return self.__frida_device.id == other.id
        elif isinstance(other, Core):
            return self.__frida_device.id == other.__frida_device.id
        return NotImplemented

    def __ne__(self, other):
        equality_result = self.__eq__(other)
        if equality_result is NotImplemented:
            return NotImplemented
        return not equality_result

    def is_frida_running(self):
        try:
            frida.get_device(self.__frida_device.id)
            return True
        except frida.ServerNotRunningError:
            return False

    def is_frida_installed(self) -> bool:
        try:
            result = subprocess.check_output(
                ['adb', '-s', self.__frida_device.id, 'shell', 'if', '[', '-f',
                 f'{FRIDA_SERVER_PATH}/frida-server', ']', ';', 'then', 'echo', 'true',
                 ';', 'else', 'echo',
                 'false', ';', 'fi'], text=True
            )
            if 'true' in result:
                return True
            else:
                return False
        except subprocess.CalledProcessError:
            return False

    def copy_frida_server_to_device(self):
        subprocess.run(
            ['adb', '-s', self.__frida_device.id, 'push',
             LOCAL_FRIDA_SERVER_PATH, FRIDA_SERVER_PATH]
        )

    def run_frida_server(self):
        subprocess.run(
            ['adb', '-s', self.__frida_device.id, 'shell',
             'nohup', f'{FRIDA_SERVER_PATH}/frida-server', '&']
        )

    @staticmethod
    def get_all_connected_devices() -> list['Core']:
        mngr = frida.get_device_manager()
        devices = mngr.enumerate_devices()
        connected_devices = [Core(device) for device in devices if
                             device.type in ["device", "usb"]]
        return connected_devices
